import Vue from 'vue'
import App from './App.vue'

import ElementUI from 'element-ui';
import VueRouter from 'vue-router';
import stores from './vuex';
import Vuex from 'vuex';
import routes from './routes/routes';

// Vue.config.silent = true;

import 'font-awesome/css/font-awesome.min.css';
import '@/utils/dialog.js';
import '@/utils/option-scroll.js';
import 'element-ui/lib/theme-chalk/index.css';
import {mixins} from '@/mixins';  //引入混合
Vue.mixin(mixins);  //使用混合


//Import Froala Editor 
import 'froala-editor/js/plugins.pkgd.min.js';
import 'froala-editor/js/plugins/quick_insert.min.js';
import 'froala-editor/js/plugins/font_size.min.js';
// import 'froala-editor/js/languages/hr.js';
//Import third party plugins
import 'froala-editor/js/third_party/embedly.min';
import 'froala-editor/js/third_party/font_awesome.min';
import 'froala-editor/js/third_party/spell_checker.min';
import 'froala-editor/js/third_party/image_tui.min';
//引入中文语言包
require('froala-editor/js/languages/zh_cn');
require('froala-editor/js/languages/hr.js');
require('froala-editor/css/froala_style.min.css');
// Import Froala Editor css files.
import 'froala-editor/css/froala_editor.pkgd.min.css';
import 'froala-editor/css/plugins/quick_insert.css';
// Import and use Vue Froala lib.
import VueFroala from 'vue-froala-wysiwyg';
Vue.use(VueFroala);

Vue.use(ElementUI);
Vue.use(VueRouter);
Vue.use(Vuex);

import icons from '@/utils/icon.js'
Vue.prototype.$icons = icons

import Clipboard from 'clipboard' // 复制
Vue.prototype.Clipboard=Clipboard

import VDistpicker from 'v-distpicker'
Vue.component('v-distpicker', VDistpicker)

import DatePicker from 'vue2-datepicker';
import 'vue2-datepicker/index.css';
import 'vue2-datepicker/locale/zh-cn';
Vue.component('date-picker',DatePicker)

import selectUnit from '@/components/selectUnit.vue'
Vue.component('selectUnit',selectUnit)

/*  */
import Vue2OrgTree from 'vue2-org-tree'
import './styles/org.scss'
// 公共样式
import './styles/index.scss'

Vue.use(Vue2OrgTree)

/* lodash */
import _ from 'lodash'
Vue.prototype._ = _

/* moment */
import moment from 'moment'
moment.locale('zh-cn')
Vue.prototype.$moment = moment

/* VueClipboard 用于拷贝 */
import VueClipboard from 'vue-clipboard2'
 
Vue.use(VueClipboard)

Vue.config.productionTip = false

export const router = new VueRouter({
	mode:"history",
	routes
})

export const store = new Vuex.Store({
	...stores
});

router.beforeEach((to, from, next) => {
	// let rddp_user_name=http.getCookie('rddp_user_name') || false;
	// let rddp_admin_access_token=http.getCookie('rddp_admin_access_token') || false;
	let auth = localStorage.getItem('auth') || false;
	if( to.path!='/login'&&(!auth)){
		window.location.href=process.env.Login;
		return false;
	}
	//面包屑
	if(to.meta.pathFrom && 
		['/customList','/customSearch','/approvalList','/potentialList','/pickList','/contractapprovallist','/contractmanagelist',
			'/expiringlist','/incrementalist','/stocklist','/chartJurisdiction','/readClassify','/contractlist','/incomelist','/newCustomlist',
		'/contractCustomlist'].includes(from.path)) {
		to.meta.pathFrom =  from.path.replace('/','')
		to.meta.pathName =  from.path == '/readClassify' ? '图库阅读统计' : from.name 
	} 
	//进入合同详情 如果从审批列表进入则改写为审批列表否则改为合同管理
	// if(to.path=='/contractdetail'){
	// 	if(from.path=='/contractapprovallist'){
	// 		to.matched[0].name='审批列表'
	// 	}else{
	// 		to.matched[0].name='合同管理'
	// 	}
	// }
	if(to.path=='/customDetail'){
		if(from.matched[0]){
			to.matched[0].name=from.matched[0].name
		}
		// if(from.path=='/approvalList'){
		// 	to.matched[0].name='审批列表'
		// }else{
		// 	to.matched[0].name='客户管理'
		// }
	}

	// 续约审批审批和补充协议审批
	if(to.path=='/approvalUpdate'&&to.query.ApplyMethod==6){
		to.matched[1].name='补充协议'
	}

	/* 沙盘详情name添加 */
	if(to.path === '/sandflow') {
		to.matched[1].name = to.query.id ? '编辑沙盘': '添加沙盘';
	}

	/* 图库阅读统计 修改下级name */
	if(to.path === '/readClassify') {
		to.matched[1].name = to.query.name;
	}

  /* ETA试用 修改面包屑 */
  if(to.path==='/etaAddApproval'){
    to.matched[1].name = sessionStorage.getItem('applyInfo')?'重新申请':'新增申请'
  }
	
	if( to.path ){
		 //百度统计
		if (window._hmt) {
			window._hmt.push(['_trackPageview', '/#' + to.fullPath])
		}
		next();
	}else{
		next({ path:'/404' });
	}
});

router.afterEach((to,from,next) => {
	//改变页面标题
	document.title = to.matched[to.matched.length-1].name ?
									`弘则-${to.matched[to.matched.length-1].name}`:'弘则管理后台'
	window.scrollTo(0,0);
	// 或
	// window.scroll(0, 0);
 });

new Vue({
  router,
  store,
  render: h => h(App),
}).$mount('#app')
