//文档管理,语义分析管理 目录的逻辑
export default {
  directives: {
    //拖拽左侧目录栏
    drag(el, bindings) {
      el.onmousedown = function (e) {
        let init = e.clientX;
        let left = $('#left')[0];
        let initWidth = left.offsetWidth;
        document.onmousemove = function (e) {
          let end = e.clientX;
          let newWidth = end - init + initWidth;
          left.style.width = newWidth+'px';
        };
        document.onmouseup = function () {
          document.onmousemove = document.onmouseup = null;
          e.releaseCapture && e.releaseCapture();
        };
        e.setCapture && e.setCapture();
        return false;
      };
    },
  },
  data() {
    return {
      model: 'list',//当前是展示目录列表还是文档详情
      searchTitle: '',//搜索文字
      searchOptions: [],//搜索结果
      listData: [],//目录信息
      expandKeys: [],//当前展开的目录
      catalogList:[],//列表信息
      selectNodeKey:'',//当前选择的节点Id
      selectNode:{},//当前选择的节点
    }
  },
  methods: {
    //节点展开时触发
    handleNodeExpand(data) {
      !this.expandKeys.includes(data.nodeKeyId)&&this.expandKeys.push(data.nodeKeyId)
    },
    //节点收起时触发
    handleNodeCollapse(data) {
      const index = this.expandKeys.findIndex(i=>i===data.nodeKeyId)
      index!==-1&&this.expandKeys.splice(index,1)
    },
    //节点改变
    nodeChange(data,node) {
      const model = node.level===1?'list':'file'
      this.changeModel(model,data)
    },
    //切换展示模式
    changeModel(model,data){
      //console.log('data',data)
      this.model = model
      this.$refs.catalogTree.setCurrentKey(data.nodeKeyId)
      this.selectNodeKey = this.$refs.catalogTree.getCurrentKey()
      this.selectNode = this.$refs.catalogTree.getCurrentNode()
      if(model==='list'){
        //get list detail
        this.catalogList = data.children||[]
      }else{
        //get file detail
        this.getDetail(data)
      }
    },
    //节点操作
    clickNodeHandle(type,data,model) {
      const handleMap = {
        'edit':this.handleEdit,
        'del':this.handleDelete
      }
      handleMap[type](model?model:this.model,data)
    },
    //列表项操作
    handleOperateCommand({key,data}){
      this.clickNodeHandle(key,data,'file')
    },
    //编辑节点
    handleEdit(model,data){
      //根据model判断编辑list还是file
      if(model==='list'){
        this.classifyForm = {
          classify_id:data.nodeKeyId,
          classify_name:data.label,
          classify_img:data.CoverImg
        }
        this.isModifyClassifyShow = true
      }else{
        //打开编辑文档页面(新增一页?)
        /* this.$router.push({
          path:'/editDocument',
          query:{fileId:data.nodeKeyId}
        }) */
        //window.open(`/editDocument?fileId=${data.nodeKeyId}`)
        this.toPage('editFile',{fileId:data.nodeKeyId})
      }
      
    },
    //删除节点
    handleDelete(model,data){
      //根据model判断删除list还是file
     if(model==='list'){
       this.deleteList(data)
     }else{
       this.deleteFile(data)
     } 
    },
    deleteList(data){
      if(this.catalogList&&this.catalogList.length!==0){
        this.$message.error('该分类下有关联文档,不允许删除')
        return
      }
      this.$confirm('删除操作不可恢复，确认删除吗？','提示',{
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        type: 'warning',
      }).then(async()=>{
        //delete list
        await this.deleteClassify(data)
        //清空currentKey 和 catalogList
        this.clearNodeInfo()
        //done getList
        this.getListData()
      }).catch(()=>{}).finally(()=>{})
    },
    deleteFile(data){
      if(data.UseNum>0){
        this.$message.error('已关联对比结果，不允许删除')
        return
      }
      this.$confirm('删除操作不可恢复，确认删除吗？','提示',{
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        type: 'warning',
      }).then(async()=>{
        //delete file
        await this.deleteDocument(data)
      }).catch(()=>{}).finally(()=>{})
    },
    async chooseDataClassify(data){
        await this.getListData()
        //done 选中所属目录
        const catalog = this.listData.find(item=>{return Number(item.nodeKeyId)===data.parentId})
        catalog&&this.nodeChange(catalog,{level:1})
        this.handleNodeExpand({nodeKeyId:data.parentId+''})
    },
    clearNodeInfo(){
      if(this.model==='list'){
        this.catalogList=[]
      }
      this.selectNodeKey=''
      this.selectNode={}
    },
    clearForm(){
      this.$refs.formRef&&this.$refs.formRef.resetFields();
      this.classifyForm={}
      this.isModifyClassifyShow = false;
    },

    //移动这期不做 加入"只看我的"功能时会用到
    /* draggable 列表移动相关 */
    dragStartHandler(){},
    dragenter(){},
    moveListItem(){},
     /*tree 节点移动相关 */
    //判断节点是否能拖拽 绑定allow-drag
    checkAllowDrag(node) {
      return true
    },
    //判断节点是否能放入 绑定allow-drop
    checkAllowDrop() {
      return true
    },
    //节点放入时触发 绑定node-drop
    handleDropOver() {},
    
  },
  async mounted(){
    await this.getListData()
    if(this.listData.length){
        const fileClassify = sessionStorage.getItem('fileClassify')||''
        const fileId = sessionStorage.getItem('fileId')||''
        if(fileClassify.length&&fileId.length){
            this.handleNodeExpand({nodeKeyId:fileClassify})
            if(this.$route.path==='/documentPage')
                this.nodeChange({SaDocId:Number(fileId),nodeKeyId:`children_${fileId}`},{level:2})
            else
            this.nodeChange({SaCompareId:Number(fileId),nodeKeyId:`children_${fileId}`},{level:2})
            sessionStorage.removeItem('fileClassify')
            sessionStorage.removeItem('fileId')
        }
    }
  }
}